Function window_node_id
pub fn window_node_id() -> u64Expand description
get window node id that won’t conflict with other node ids for the duration of the program
pub fn window_node_id() -> u64get window node id that won’t conflict with other node ids for the duration of the program